import Foundation
import SwiftUI
import SFSafeSymbols

struct TagView: View {

    static let background = Color(r: 9, g: 62, b: 103)

    static let foreground = Color(r: 96, g: 186, b: 255)

    @Environment(\.language)
    var language: ContentLanguage

    let tag: LocalizedText

    let icon: SFSymbol

    let iconSize: CGFloat

    init(tag: LocalizedText, icon: SFSymbol = .xCircleFill, iconSize: CGFloat = 12.0) {
        self.tag = tag
        self.icon = icon
        self.iconSize = iconSize
    }

    static var add: TagView {
        .init(tag: LocalizedText(en: "Add", de: "Mehr"), icon: .plusCircleFill)
    }

    var body: some View {
        HStack {
            Text(tag.getText(for: language))
                .font(.subheadline)
                .padding(.leading, 2)
            SwiftUI.Image(systemSymbol: icon)
                .font(.system(size: iconSize, weight: .black, design: .rounded))
                .opacity(0.7)
                .padding(.leading, -5)
        }
        .foregroundColor(TagView.foreground)
        .font(.caption2)
        .padding(.horizontal, 8)
        .padding(.vertical, 4)
        .background(TagView.background)
        .cornerRadius(8)
    }
}

#Preview {
    HStack {
        TagView(tag: LocalizedText(en: "Some", de: "Etwas"))
            .environment(\.language, ContentLanguage.german)
        TagView(tag: LocalizedText(en: "Some", de: "Etwas"))
            .environment(\.language, ContentLanguage.english)
        TagView.add
    }
}
